@@ -14,8 +14,8 @@ prod_mapper = {
 def get_current_client(prod):
     module = importlib.import_module('cloudplatform_auth')
     get_access_func = getattr(module, 'get_alicloud_access_info')
-    access_key_id, access_key_secret, region = get_access_func()
-    return prod_mapper[prod](access_key_id, access_key_secret, region)
+    access_key_id, access_key_secret, region, config = get_access_func()
+    return prod_mapper[prod](access_key_id, access_key_secret, region, config)
 
 
 @proxy
