@@ -75,7 +75,9 @@ class AliNas:
 
     @property
     def capacity(self):
-        return '{}(GB)'.format(self.nas_info.get('Capacity') or self.nas_info.get('QuotaSize'))
+        quota_size = self.nas_info.get('QuotaSize')
+        capacity = round(quota_size / 1073741824, 2) if quota_size else None
+        return self.nas_info.get('Capacity') or capacity
 
     @property
     def mount_targets(self):
