@@ -1,5 +1,5 @@
 from .client import HuaweiClient
-from huaweicloudsdkeip.v2 import EipClient, CreatePublicipRequest, DeletePublicipRequest, ShowPublicipRequest, \
+from huaweicloudsdkeip.v2 import EipClient, CreatePrePaidPublicipRequest, DeletePublicipRequest, ShowPublicipRequest, \
     UpdatePublicipRequest
 from huaweicloudsdkeip.v2.region.eip_region import EipRegion
 
@@ -13,8 +13,8 @@ class HuaweiEipClient(HuaweiClient):
         return self.generate_client(EipClient, EipRegion)
 
     def create_eip(self, body_params=None):
-        request = CreatePublicipRequest(body=body_params)
-        return self.eip_client.create_publicip(request)
+        request = CreatePrePaidPublicipRequest(body=body_params)
+        return self.eip_client.create_pre_paid_publicip(request)
 
     def delete_eip(self, publicip_id=None):
         request = DeletePublicipRequest(publicip_id=publicip_id)
